<a id="mypy-boto3-cloudfront"></a>

# mypy-boto3-cloudfront

[![PyPI - mypy-boto3-cloudfront](https://img.shields.io/pypi/v/mypy-boto3-cloudfront.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloudfront)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-cloudfront.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloudfront)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-cloudfront?color=blue)](https://pypistats.org/packages/mypy-boto3-cloudfront)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.CloudFront 1.23.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudfront.html#CloudFront)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.5.14](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-cloudfront docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudfront/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-cloudfront](#mypy-boto3-cloudfront)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `CloudFront`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `CloudFront` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[cloudfront]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[cloudfront]'


# standalone installation
python -m pip install mypy-boto3-cloudfront
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-cloudfront
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[cloudfront]` in your environment:

```bash
python -m pip install 'boto3-stubs[cloudfront]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[cloudfront]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[cloudfront]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[cloudfront]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[cloudfront]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[cloudfront]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[cloudfront]` in your environment:

```bash
python -m pip install 'boto3-stubs[cloudfront]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[cloudfront]` in your environment:

```bash
python -m pip install 'boto3-stubs[cloudfront]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CloudFrontClient` provides annotations for `boto3.client("cloudfront")`.

```python
from boto3.session import Session

from mypy_boto3_cloudfront import CloudFrontClient

client: CloudFrontClient = Session().client("cloudfront")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_cloudfront.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_cloudfront import CloudFrontClient
from mypy_boto3_cloudfront.paginator import (
    ListCloudFrontOriginAccessIdentitiesPaginator,
    ListDistributionsPaginator,
    ListInvalidationsPaginator,
    ListStreamingDistributionsPaginator,
)

client: CloudFrontClient = Session().client("cloudfront")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_cloud_front_origin_access_identities_paginator: ListCloudFrontOriginAccessIdentitiesPaginator = client.get_paginator("list_cloud_front_origin_access_identities")
list_distributions_paginator: ListDistributionsPaginator = client.get_paginator("list_distributions")
list_invalidations_paginator: ListInvalidationsPaginator = client.get_paginator("list_invalidations")
list_streaming_distributions_paginator: ListStreamingDistributionsPaginator = client.get_paginator("list_streaming_distributions")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_cloudfront.waiter` module contains type annotations for all
waiters.

```python
from boto3.session import Session

from mypy_boto3_cloudfront import CloudFrontClient
from mypy_boto3_cloudfront.waiter import (
    DistributionDeployedWaiter,
    InvalidationCompletedWaiter,
    StreamingDistributionDeployedWaiter,
)

client: CloudFrontClient = Session().client("cloudfront")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
distribution_deployed_waiter: DistributionDeployedWaiter = client.get_waiter("distribution_deployed")
invalidation_completed_waiter: InvalidationCompletedWaiter = client.get_waiter("invalidation_completed")
streaming_distribution_deployed_waiter: StreamingDistributionDeployedWaiter = client.get_waiter("streaming_distribution_deployed")
```

<a id="literals"></a>

### Literals

`mypy_boto3_cloudfront.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_cloudfront.literals import (
    CachePolicyCookieBehaviorType,
    CachePolicyHeaderBehaviorType,
    CachePolicyQueryStringBehaviorType,
    CachePolicyTypeType,
    CertificateSourceType,
    DistributionDeployedWaiterName,
    EventTypeType,
    FormatType,
    FrameOptionsListType,
    FunctionRuntimeType,
    FunctionStageType,
    GeoRestrictionTypeType,
    HttpVersionType,
    ICPRecordalStatusType,
    InvalidationCompletedWaiterName,
    ItemSelectionType,
    ListCloudFrontOriginAccessIdentitiesPaginatorName,
    ListDistributionsPaginatorName,
    ListInvalidationsPaginatorName,
    ListStreamingDistributionsPaginatorName,
    MethodType,
    MinimumProtocolVersionType,
    OriginProtocolPolicyType,
    OriginRequestPolicyCookieBehaviorType,
    OriginRequestPolicyHeaderBehaviorType,
    OriginRequestPolicyQueryStringBehaviorType,
    OriginRequestPolicyTypeType,
    PriceClassType,
    RealtimeMetricsSubscriptionStatusType,
    ReferrerPolicyListType,
    ResponseHeadersPolicyAccessControlAllowMethodsValuesType,
    ResponseHeadersPolicyTypeType,
    SSLSupportMethodType,
    SslProtocolType,
    StreamingDistributionDeployedWaiterName,
    ViewerProtocolPolicyType,
    CloudFrontServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: CachePolicyCookieBehaviorType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_cloudfront.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_cloudfront.type_defs import (
    ActiveTrustedKeyGroupsTypeDef,
    ActiveTrustedSignersTypeDef,
    AliasICPRecordalTypeDef,
    AliasesTypeDef,
    AllowedMethodsTypeDef,
    AssociateAliasRequestRequestTypeDef,
    CacheBehaviorTypeDef,
    CacheBehaviorsTypeDef,
    CachePolicyConfigTypeDef,
    CachePolicyCookiesConfigTypeDef,
    CachePolicyHeadersConfigTypeDef,
    CachePolicyListTypeDef,
    CachePolicyQueryStringsConfigTypeDef,
    CachePolicySummaryTypeDef,
    CachePolicyTypeDef,
    CachedMethodsTypeDef,
    CloudFrontOriginAccessIdentityConfigTypeDef,
    CloudFrontOriginAccessIdentityListTypeDef,
    CloudFrontOriginAccessIdentitySummaryTypeDef,
    CloudFrontOriginAccessIdentityTypeDef,
    ConflictingAliasTypeDef,
    ConflictingAliasesListTypeDef,
    ContentTypeProfileConfigTypeDef,
    ContentTypeProfileTypeDef,
    ContentTypeProfilesTypeDef,
    CookieNamesTypeDef,
    CookiePreferenceTypeDef,
    CreateCachePolicyRequestRequestTypeDef,
    CreateCachePolicyResultTypeDef,
    CreateCloudFrontOriginAccessIdentityRequestRequestTypeDef,
    CreateCloudFrontOriginAccessIdentityResultTypeDef,
    CreateDistributionRequestRequestTypeDef,
    CreateDistributionResultTypeDef,
    CreateDistributionWithTagsRequestRequestTypeDef,
    CreateDistributionWithTagsResultTypeDef,
    CreateFieldLevelEncryptionConfigRequestRequestTypeDef,
    CreateFieldLevelEncryptionConfigResultTypeDef,
    CreateFieldLevelEncryptionProfileRequestRequestTypeDef,
    CreateFieldLevelEncryptionProfileResultTypeDef,
    CreateFunctionRequestRequestTypeDef,
    CreateFunctionResultTypeDef,
    CreateInvalidationRequestRequestTypeDef,
    CreateInvalidationResultTypeDef,
    CreateKeyGroupRequestRequestTypeDef,
    CreateKeyGroupResultTypeDef,
    CreateMonitoringSubscriptionRequestRequestTypeDef,
    CreateMonitoringSubscriptionResultTypeDef,
    CreateOriginRequestPolicyRequestRequestTypeDef,
    CreateOriginRequestPolicyResultTypeDef,
    CreatePublicKeyRequestRequestTypeDef,
    CreatePublicKeyResultTypeDef,
    CreateRealtimeLogConfigRequestRequestTypeDef,
    CreateRealtimeLogConfigResultTypeDef,
    CreateResponseHeadersPolicyRequestRequestTypeDef,
    CreateResponseHeadersPolicyResultTypeDef,
    CreateStreamingDistributionRequestRequestTypeDef,
    CreateStreamingDistributionResultTypeDef,
    CreateStreamingDistributionWithTagsRequestRequestTypeDef,
    CreateStreamingDistributionWithTagsResultTypeDef,
    CustomErrorResponseTypeDef,
    CustomErrorResponsesTypeDef,
    CustomHeadersTypeDef,
    CustomOriginConfigTypeDef,
    DefaultCacheBehaviorTypeDef,
    DeleteCachePolicyRequestRequestTypeDef,
    DeleteCloudFrontOriginAccessIdentityRequestRequestTypeDef,
    DeleteDistributionRequestRequestTypeDef,
    DeleteFieldLevelEncryptionConfigRequestRequestTypeDef,
    DeleteFieldLevelEncryptionProfileRequestRequestTypeDef,
    DeleteFunctionRequestRequestTypeDef,
    DeleteKeyGroupRequestRequestTypeDef,
    DeleteMonitoringSubscriptionRequestRequestTypeDef,
    DeleteOriginRequestPolicyRequestRequestTypeDef,
    DeletePublicKeyRequestRequestTypeDef,
    DeleteRealtimeLogConfigRequestRequestTypeDef,
    DeleteResponseHeadersPolicyRequestRequestTypeDef,
    DeleteStreamingDistributionRequestRequestTypeDef,
    DescribeFunctionRequestRequestTypeDef,
    DescribeFunctionResultTypeDef,
    DistributionConfigTypeDef,
    DistributionConfigWithTagsTypeDef,
    DistributionIdListTypeDef,
    DistributionListTypeDef,
    DistributionSummaryTypeDef,
    DistributionTypeDef,
    EncryptionEntitiesTypeDef,
    EncryptionEntityTypeDef,
    EndPointTypeDef,
    FieldLevelEncryptionConfigTypeDef,
    FieldLevelEncryptionListTypeDef,
    FieldLevelEncryptionProfileConfigTypeDef,
    FieldLevelEncryptionProfileListTypeDef,
    FieldLevelEncryptionProfileSummaryTypeDef,
    FieldLevelEncryptionProfileTypeDef,
    FieldLevelEncryptionSummaryTypeDef,
    FieldLevelEncryptionTypeDef,
    FieldPatternsTypeDef,
    ForwardedValuesTypeDef,
    FunctionAssociationTypeDef,
    FunctionAssociationsTypeDef,
    FunctionConfigTypeDef,
    FunctionListTypeDef,
    FunctionMetadataTypeDef,
    FunctionSummaryTypeDef,
    GeoRestrictionTypeDef,
    GetCachePolicyConfigRequestRequestTypeDef,
    GetCachePolicyConfigResultTypeDef,
    GetCachePolicyRequestRequestTypeDef,
    GetCachePolicyResultTypeDef,
    GetCloudFrontOriginAccessIdentityConfigRequestRequestTypeDef,
    GetCloudFrontOriginAccessIdentityConfigResultTypeDef,
    GetCloudFrontOriginAccessIdentityRequestRequestTypeDef,
    GetCloudFrontOriginAccessIdentityResultTypeDef,
    GetDistributionConfigRequestRequestTypeDef,
    GetDistributionConfigResultTypeDef,
    GetDistributionRequestDistributionDeployedWaitTypeDef,
    GetDistributionRequestRequestTypeDef,
    GetDistributionResultTypeDef,
    GetFieldLevelEncryptionConfigRequestRequestTypeDef,
    GetFieldLevelEncryptionConfigResultTypeDef,
    GetFieldLevelEncryptionProfileConfigRequestRequestTypeDef,
    GetFieldLevelEncryptionProfileConfigResultTypeDef,
    GetFieldLevelEncryptionProfileRequestRequestTypeDef,
    GetFieldLevelEncryptionProfileResultTypeDef,
    GetFieldLevelEncryptionRequestRequestTypeDef,
    GetFieldLevelEncryptionResultTypeDef,
    GetFunctionRequestRequestTypeDef,
    GetFunctionResultTypeDef,
    GetInvalidationRequestInvalidationCompletedWaitTypeDef,
    GetInvalidationRequestRequestTypeDef,
    GetInvalidationResultTypeDef,
    GetKeyGroupConfigRequestRequestTypeDef,
    GetKeyGroupConfigResultTypeDef,
    GetKeyGroupRequestRequestTypeDef,
    GetKeyGroupResultTypeDef,
    GetMonitoringSubscriptionRequestRequestTypeDef,
    GetMonitoringSubscriptionResultTypeDef,
    GetOriginRequestPolicyConfigRequestRequestTypeDef,
    GetOriginRequestPolicyConfigResultTypeDef,
    GetOriginRequestPolicyRequestRequestTypeDef,
    GetOriginRequestPolicyResultTypeDef,
    GetPublicKeyConfigRequestRequestTypeDef,
    GetPublicKeyConfigResultTypeDef,
    GetPublicKeyRequestRequestTypeDef,
    GetPublicKeyResultTypeDef,
    GetRealtimeLogConfigRequestRequestTypeDef,
    GetRealtimeLogConfigResultTypeDef,
    GetResponseHeadersPolicyConfigRequestRequestTypeDef,
    GetResponseHeadersPolicyConfigResultTypeDef,
    GetResponseHeadersPolicyRequestRequestTypeDef,
    GetResponseHeadersPolicyResultTypeDef,
    GetStreamingDistributionConfigRequestRequestTypeDef,
    GetStreamingDistributionConfigResultTypeDef,
    GetStreamingDistributionRequestRequestTypeDef,
    GetStreamingDistributionRequestStreamingDistributionDeployedWaitTypeDef,
    GetStreamingDistributionResultTypeDef,
    HeadersTypeDef,
    InvalidationBatchTypeDef,
    InvalidationListTypeDef,
    InvalidationSummaryTypeDef,
    InvalidationTypeDef,
    KGKeyPairIdsTypeDef,
    KeyGroupConfigTypeDef,
    KeyGroupListTypeDef,
    KeyGroupSummaryTypeDef,
    KeyGroupTypeDef,
    KeyPairIdsTypeDef,
    KinesisStreamConfigTypeDef,
    LambdaFunctionAssociationTypeDef,
    LambdaFunctionAssociationsTypeDef,
    ListCachePoliciesRequestRequestTypeDef,
    ListCachePoliciesResultTypeDef,
    ListCloudFrontOriginAccessIdentitiesRequestListCloudFrontOriginAccessIdentitiesPaginateTypeDef,
    ListCloudFrontOriginAccessIdentitiesRequestRequestTypeDef,
    ListCloudFrontOriginAccessIdentitiesResultTypeDef,
    ListConflictingAliasesRequestRequestTypeDef,
    ListConflictingAliasesResultTypeDef,
    ListDistributionsByCachePolicyIdRequestRequestTypeDef,
    ListDistributionsByCachePolicyIdResultTypeDef,
    ListDistributionsByKeyGroupRequestRequestTypeDef,
    ListDistributionsByKeyGroupResultTypeDef,
    ListDistributionsByOriginRequestPolicyIdRequestRequestTypeDef,
    ListDistributionsByOriginRequestPolicyIdResultTypeDef,
    ListDistributionsByRealtimeLogConfigRequestRequestTypeDef,
    ListDistributionsByRealtimeLogConfigResultTypeDef,
    ListDistributionsByResponseHeadersPolicyIdRequestRequestTypeDef,
    ListDistributionsByResponseHeadersPolicyIdResultTypeDef,
    ListDistributionsByWebACLIdRequestRequestTypeDef,
    ListDistributionsByWebACLIdResultTypeDef,
    ListDistributionsRequestListDistributionsPaginateTypeDef,
    ListDistributionsRequestRequestTypeDef,
    ListDistributionsResultTypeDef,
    ListFieldLevelEncryptionConfigsRequestRequestTypeDef,
    ListFieldLevelEncryptionConfigsResultTypeDef,
    ListFieldLevelEncryptionProfilesRequestRequestTypeDef,
    ListFieldLevelEncryptionProfilesResultTypeDef,
    ListFunctionsRequestRequestTypeDef,
    ListFunctionsResultTypeDef,
    ListInvalidationsRequestListInvalidationsPaginateTypeDef,
    ListInvalidationsRequestRequestTypeDef,
    ListInvalidationsResultTypeDef,
    ListKeyGroupsRequestRequestTypeDef,
    ListKeyGroupsResultTypeDef,
    ListOriginRequestPoliciesRequestRequestTypeDef,
    ListOriginRequestPoliciesResultTypeDef,
    ListPublicKeysRequestRequestTypeDef,
    ListPublicKeysResultTypeDef,
    ListRealtimeLogConfigsRequestRequestTypeDef,
    ListRealtimeLogConfigsResultTypeDef,
    ListResponseHeadersPoliciesRequestRequestTypeDef,
    ListResponseHeadersPoliciesResultTypeDef,
    ListStreamingDistributionsRequestListStreamingDistributionsPaginateTypeDef,
    ListStreamingDistributionsRequestRequestTypeDef,
    ListStreamingDistributionsResultTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResultTypeDef,
    LoggingConfigTypeDef,
    MonitoringSubscriptionTypeDef,
    OriginCustomHeaderTypeDef,
    OriginGroupFailoverCriteriaTypeDef,
    OriginGroupMemberTypeDef,
    OriginGroupMembersTypeDef,
    OriginGroupTypeDef,
    OriginGroupsTypeDef,
    OriginRequestPolicyConfigTypeDef,
    OriginRequestPolicyCookiesConfigTypeDef,
    OriginRequestPolicyHeadersConfigTypeDef,
    OriginRequestPolicyListTypeDef,
    OriginRequestPolicyQueryStringsConfigTypeDef,
    OriginRequestPolicySummaryTypeDef,
    OriginRequestPolicyTypeDef,
    OriginShieldTypeDef,
    OriginSslProtocolsTypeDef,
    OriginTypeDef,
    OriginsTypeDef,
    PaginatorConfigTypeDef,
    ParametersInCacheKeyAndForwardedToOriginTypeDef,
    PathsTypeDef,
    PublicKeyConfigTypeDef,
    PublicKeyListTypeDef,
    PublicKeySummaryTypeDef,
    PublicKeyTypeDef,
    PublishFunctionRequestRequestTypeDef,
    PublishFunctionResultTypeDef,
    QueryArgProfileConfigTypeDef,
    QueryArgProfileTypeDef,
    QueryArgProfilesTypeDef,
    QueryStringCacheKeysTypeDef,
    QueryStringNamesTypeDef,
    RealtimeLogConfigTypeDef,
    RealtimeLogConfigsTypeDef,
    RealtimeMetricsSubscriptionConfigTypeDef,
    ResponseHeadersPolicyAccessControlAllowHeadersTypeDef,
    ResponseHeadersPolicyAccessControlAllowMethodsTypeDef,
    ResponseHeadersPolicyAccessControlAllowOriginsTypeDef,
    ResponseHeadersPolicyAccessControlExposeHeadersTypeDef,
    ResponseHeadersPolicyConfigTypeDef,
    ResponseHeadersPolicyContentSecurityPolicyTypeDef,
    ResponseHeadersPolicyContentTypeOptionsTypeDef,
    ResponseHeadersPolicyCorsConfigTypeDef,
    ResponseHeadersPolicyCustomHeaderTypeDef,
    ResponseHeadersPolicyCustomHeadersConfigTypeDef,
    ResponseHeadersPolicyFrameOptionsTypeDef,
    ResponseHeadersPolicyListTypeDef,
    ResponseHeadersPolicyReferrerPolicyTypeDef,
    ResponseHeadersPolicySecurityHeadersConfigTypeDef,
    ResponseHeadersPolicyServerTimingHeadersConfigTypeDef,
    ResponseHeadersPolicyStrictTransportSecurityTypeDef,
    ResponseHeadersPolicySummaryTypeDef,
    ResponseHeadersPolicyTypeDef,
    ResponseHeadersPolicyXSSProtectionTypeDef,
    ResponseMetadataTypeDef,
    RestrictionsTypeDef,
    S3OriginConfigTypeDef,
    S3OriginTypeDef,
    SignerTypeDef,
    StatusCodesTypeDef,
    StreamingDistributionConfigTypeDef,
    StreamingDistributionConfigWithTagsTypeDef,
    StreamingDistributionListTypeDef,
    StreamingDistributionSummaryTypeDef,
    StreamingDistributionTypeDef,
    StreamingLoggingConfigTypeDef,
    TagKeysTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TagsTypeDef,
    TestFunctionRequestRequestTypeDef,
    TestFunctionResultTypeDef,
    TestResultTypeDef,
    TrustedKeyGroupsTypeDef,
    TrustedSignersTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateCachePolicyRequestRequestTypeDef,
    UpdateCachePolicyResultTypeDef,
    UpdateCloudFrontOriginAccessIdentityRequestRequestTypeDef,
    UpdateCloudFrontOriginAccessIdentityResultTypeDef,
    UpdateDistributionRequestRequestTypeDef,
    UpdateDistributionResultTypeDef,
    UpdateFieldLevelEncryptionConfigRequestRequestTypeDef,
    UpdateFieldLevelEncryptionConfigResultTypeDef,
    UpdateFieldLevelEncryptionProfileRequestRequestTypeDef,
    UpdateFieldLevelEncryptionProfileResultTypeDef,
    UpdateFunctionRequestRequestTypeDef,
    UpdateFunctionResultTypeDef,
    UpdateKeyGroupRequestRequestTypeDef,
    UpdateKeyGroupResultTypeDef,
    UpdateOriginRequestPolicyRequestRequestTypeDef,
    UpdateOriginRequestPolicyResultTypeDef,
    UpdatePublicKeyRequestRequestTypeDef,
    UpdatePublicKeyResultTypeDef,
    UpdateRealtimeLogConfigRequestRequestTypeDef,
    UpdateRealtimeLogConfigResultTypeDef,
    UpdateResponseHeadersPolicyRequestRequestTypeDef,
    UpdateResponseHeadersPolicyResultTypeDef,
    UpdateStreamingDistributionRequestRequestTypeDef,
    UpdateStreamingDistributionResultTypeDef,
    ViewerCertificateTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> ActiveTrustedKeyGroupsTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-cloudfront` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudfront/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
